pub struct TempoHeaderResponse {
pub inner: Header<TempoHeader>,
pub timestamp_millis: u64,
}Expand description
Tempo RPC header response type.
Fields
inner: Header<TempoHeader>Inner [Header].
timestamp_millis: u64Block timestamp in milliseconds.
Methods from Deref<Target = Header<TempoHeader>>
pub fn blob_fee(&self) -> Option<u128>
pub fn blob_fee(&self) -> Option<u128>
Returns the blob fee for this block according to the EIP-4844 spec.
Returns None if excess_blob_gas is None
pub fn next_block_blob_fee(&self, blob_params: BlobParams) -> Option<u128>
pub fn next_block_blob_fee(&self, blob_params: BlobParams) -> Option<u128>
Returns the blob fee for the next block according to the EIP-4844 spec.
Returns None if excess_blob_gas is None.
See also [Self::next_block_excess_blob_gas]
pub fn next_block_excess_blob_gas(&self, blob_params: BlobParams) -> Option<u64>
pub fn next_block_excess_blob_gas(&self, blob_params: BlobParams) -> Option<u64>
Calculate excess blob gas for the next block according to the EIP-4844 spec.
Returns a None if no excess blob gas is set, no EIP-4844 support